class DockerConfig:
    """Docker constants."""

    NETWORK_DEFAULT = "apisrun_network"
    APISRUN_PORT_DEFAULT = 8000

    MONGO_PORT_DEFAULT = 27017
    SERVICE_NAME = "{}_apisrun"
    IMAGE_DEFAULT = "josesalasdev/apisrun:latest"
    APISRUN_MONGO_URI = "mongodb://apisrun:password@{name}:{port}/"

    SERVICE_MONGO_NAME = "{}_mongo_apisrun"
    IMAGE_MONGO = "mongo:latest"
    MONGO_ENVS = {
        "MONGO_INITDB_ROOT_USERNAME": "apisrun",
        "MONGO_INITDB_ROOT_PASSWORD": "password",
    }
    LABELS_API = {"apisrun": "api"}
    LABELS_DB = {"apisrun": "db"}


class DockerStatus:
    """Docker container status."""

    RUNNING = "running"


class ApisrunAdmin:
    """Apisrun endpoint admin."""

    FILE_DEFAULT = "apisrun.yml"
    DEFAULT_HOST = "0.0.0.0"
    PING = "http://0.0.0.0:{port}/ping/"
    NODE = "http://0.0.0.0:{port}/admin/nodes/"


class ApisrunErrorMsg:
    """Apisrun CLI errors."""

    CONTAINER_ERROR = "💔 Error creating `{}` container. :exclamation:"
    CONTAINER_DB_ERROR = "💔 Error creating `{}` DB container. :exclamation:"
    PUSH_DATA_API_ERROR = (
        "💔 There were some errors when pushing the data" " in `{}` :exclamation:"
    )
    FILE_NOT_FOUND = "💔 File not found in `{}` :exclamation:"
    VALIDATING_FILE = "💔 Error validating yml structure in `{}` :exclamation:"


class ApisrunMsg:
    """Apisrun CLI Messages."""

    CREATING_API_CONTAINER = "🔄 Creating Api Container `{}`."
    API_CONTAINER_DONE = (
        "🟢 Api Container `{}` is ready and "
        "listening on port [bold cyan]{}[/bold cyan]."
    )
    CREATING_DB_CONTAINER = "🔄 Creating DB Container `{}`."
    DB_CONTAINER_DONE = (
        "🟢 DB Container `{}` is ready and "
        "listening on port [bold cyan]{}[/bold cyan]."
    )
    PUSH_DATA = "🆙 Pushing data to Api `{}`."
    SERVICE_DONE = "✨ Your Api `{}` was published and is ready to use."
    SERVICE_KILL = "✨ Your apis were removed. ✨"
