import yaml
import os
import socket
from contextlib import closing


def validate_path_file(path_file) -> bool:
    """Validate th path of a file."""
    if os.path.exists(path_file) and os.path.isfile(path_file):
        if os.access(path_file, os.R_OK):
            return True
    return False


def load_yaml(path_file: str):
    """Transform a yml to dict"""
    yaml_file = open(path_file, "r")
    return yaml.load(yaml_file, yaml.Loader)


def validate_errors_apisrun_yml(data) -> bool:
    """Validate apisrun data yml."""
    if len(data) < 1 and type(data) is not dict:
        return True

    error = False
    # TODO: Refactor
    for _, endpoints in data.items():
        if type(endpoints) is not list or len(endpoints) < 1:
            error = True
        for v in endpoints:
            if type(v) is not dict or len(v) < 3:
                error = True
    return error


def singleton(class_):
    """Singleton"""
    instances = {}

    def getinstance(*args, **kwargs):
        if class_ not in instances:
            instances[class_] = class_(*args, **kwargs)
        return instances[class_]

    return getinstance


def has_open_port(host, port):
    """Validate if the host port is open."""
    with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as sock:
        if sock.connect_ex((host, port)) == 0:
            return False
        return True
